function [xp,varargout] = BuckBoostModel(x,mod,cont,varargin)
% Model of the buck-boost converter (bilinear model).
% 
% xp = BuckBoostModel(x,mod,cont)
% [xp,u] = BuckBoostModel(x,mod,cont)
% xp = BuckBoostModel(x,mod,[],u)
% 
% inputs:
% x : current state of the system (n x 1)
% mod : structure consisting of all model parameters (for the buck-boost
% converter these are A0 (n x n), B0 (n x m), B{1} (n x m) and B{2} (n x
% m))
% cont : structure consisting of the controller gain K (m x n)
% u : input of the system (m x 1)
% 
% outputs:
% xp : next state of the system (first consecutive state) (n x 1)
% u : control input of the system (m x 1)
% 
% Rik Koch (TU Delft, 2021)

if (nargin > 3)
    u = varargin{1};
else
    u = cont.K*x;
end
xp = mod.A0*x + mod.B0*u + [diag(x'*mod.B{1}*u)';diag(x'*mod.B{2}*u)'];
if (nargout > 1)
    varargout{1} = u;
end
end