function [xp,varargout] = PMSMModel(x,mod,cont,varargin)
% Model of the PMSM (quadratic model).
% 
% xp = PMSMModel(x,mod,cont)
% [xp,u] = PMSMModel(x,mod,cont)
% xp = PMSMModel(x,mod,[],u)
% 
% inputs:
% x : current state of the system (n x 1)
% mod : structure consisting of all model parameters (for the PMSM
% these are A0 (n x n), A{1} (n x n), A{2} (n x n) and B0 (n x m))
% cont : structure consisting of the controller gain K (m x n)
% u : input of the system (m x 1)
% 
% outputs:
% xp : next state of the system (first consecutive state) (n x 1)
% u : control input of the system (m x 1)
%
% Rik Koch (TU Delft, 2021)

if (nargin > 3)
    u = varargin{1};
else
    u = cont.K*x;
end
xp = mod.A0*x + [diag(x'*mod.A{1}*x)';diag(x'*mod.A{2}*x)';diag(x'*mod.A{3}*x)'] + mod.B0*u;
if (nargout > 1)
    varargout{1} = u;
end
end