function bounds = findboundsellipsoid(P,varargin)
% Determines the minimum box which contains the ellipsoid. The ellipse is
% given by x'*P*x <= b
% bounds = findboundsellipsoid(P)
% bounds = findboundsellipsoid(P,b)
% bounds are the vertices of the box
% 
% Rik Koch (TU Delft, 2021)

delta = 1e-3;
n = size(P,1);
if (nargin > 1 && ~isempty(varargin{1}))
    b = varargin{1};
else
    b = 1;
end
x(:,1) = 1./sqrt(eig(P/b));
y = perms(x)';
for i = 1:size(y,2)
    s = diag(diag(y(:,i))'*P*diag(y(:,i)));
    if (min(s) > 1-delta && max(s) < 1+delta)
        break;
    end
end
if (nargin > 2 && ~isempty(varargin{2}))
    c = varargin{2};
else
    c = zeros(n,1);
end
bounds = [-y(:,i)+c y(:,i)+c];
end