% Approximate the inverse functions used in the random algorithm used to
% sample points within an ellipsoid using PWA functions
% 
% Rik Koch (TU Delft, 2021)

clear, close all;
x(:,1) = linspace(0,pi,3e6);
y(:,1) = 0.5 - 0.5*cos(x);
y(:,2) = (1/pi).*x - 1/(2*pi)*sin(2.*x);
y(:,3) = 0.5 - (9/16)*cos(x) + (1/16)*cos(3.*x);
y(:,4) = (1/pi).*x - (2/(3*pi))*sin(2.*x) + (1/(12*pi))*sin(4.*x);
y(:,5) = 0.5 - (75/128)*cos(x) + (25/256)*cos(3.*x) - (3/256)*cos(5.*x);
y(:,6) = (1/pi).*x - (3/(4*pi))*sin(2.*x) + (3/(20*pi))*sin(4.*x) - (1/(60*pi))*sin(6.*x);
yc = [0,0.005,0.01,0.02,0.04,0.08,0.16,0.32,0.68,0.84,0.92,0.96,0.98,0.99,0.995,1]';
xc(1,1:size(y,2)) = 0;
xc(size(yc,1),1:size(y,2)) = pi;
delta = 1e-5;
for i = 2:size(yc,1)-1
    indexc = (y == yc(i));
    if (sum(indexc) == 0)
        indexc = (y > yc(i) - delta) & (y < yc(i) + delta);
    end
    for j = 1:size(y,2)
        xc(i,j) = mean(x(indexc(:,j)),1);
    end
end
for i = 1:size(yc,1)-1
    a(i,:) = (xc(i+1,:)-xc(i,:))./(yc(i+1)-yc(i));
    b(i,:) = xc(i,:) - a(i,:).*yc(i);
    for j = 1:size(y,2)
        yi = [yc(i);yc(i+1)];
        figure(j), hold on, plot(yi,a(i,j).*yi+b(i,j));
    end
end
pwainvellipse.a = a;
pwainvellipse.b = b;
pwainvellipse.c = yc;
save('pwainvellipse','pwainvellipse');