function [Kout,setPout,t] = doa_quad_model_lfl(setP0,s0,sast,zeta,maxiter,add_vertices,setX,setU,mod)
% Determine the local controller (linear control gain) with corresponding
% domain of attraction using a linear Lyapunov function.
% [Kout,setPout,t] = doa_quad_model_lfl(setP0,s0,sast,zeta,maxiter,add_vertices,setX,setU,mod)
% 
% inputs:
% setP0 : initial DOA
% s0 : initial increase of distance between the origin and the vertices
% sast : minimum increase of the distance between the origin and the
% vertices
% zeta : change of value of s
% maxiter : maximum number of iterations of this method
% add_vertices : number of times additional vertices are added to the DOA
% setX : set of allowable states (A*x <= 1)
% setU : set of allowable inputs (M*u <= um)
% mod : quadratic model of the system (A0, A{}, B0, B{})
% 
% outputs:
% Kout : linear control gain
% setPout : final DOA of the local controller
% t : computational time of this method
% 
% Rik Koch (TU Delft, 2021)

t = 0;
setP{1,1} = setP0;
s = s0;
load_file = false;

enlarged = 1;
i = 1;
j = 0;
l = 1;
while(enlarged)
    enlarged  = 0;
    v = setP{i,1}.v;
    for k = 1:size(v,2)
        if (load_file)
            load('data_inverter_pmsm_lfl_63.mat');
            k = k + 1;
            load_file = false;
        end
        disp(['i = ' num2str(i) ', s = ' num2str(s) ' (' num2str(size(v,2)) ' vertices (' num2str(k) ', ' num2str(j+1) '))']);
%         if (max(setX.A'*v(:,k)) < 0.9999)
            vnew = (1 + s)*v(:,k);
            setP1.A = vert2con([setP{i}.v vnew]')';
            setP1.v = con2vert([setP1.A setX.A]')';
            setP1.A = vert2con(setP1.v')';
%         setPt = intersect(Polyhedron([setP{i,1}.v';vnew']),Polyhedron(setX.v'));
%         if (volume(setPt) > volume(Polyhedron(setP{i,1}.v')))
        if (volume(Polyhedron(setP1.v')) > volume(Polyhedron(setP{i,1}.v')))
%         if (max(setP{i,1}.A'*vnew) > 1)
%             setPt.A = vert2con([setP{i,1}.v';vnew'])';
%             setPt.v = con2vert([setPt.A setX.A]')';
%             setPt.A = vert2con(setPt.v')';
            j = j + 1;
%             setP1.A = (setPt.A./setPt.b)';
%             setP1.v = setPt.V';
            [Kt,epsilon,t0] = LFLDetContr2(mod,setP1,setU);
            t = t + t0;
            if (epsilon < 1)
                setP{i+1,1} = setP1;
                K{i,1} = Kt;
                i = i + 1;
                enlarged = 1;
            end
        end
%         if (j >= 1)
%             if (modulo(j,10) == 0)
%                 save(['data_inverter_pmsm_lfl_',num2str(j),'.mat']);
%             end
%         end
    end
    if (j > maxiter)
        break;
    end
    if (enlarged == 0 && s > sast)
        if (max(size(zeta)) > 1)
            if (l <= max(size(zeta)))
                s = s0/zeta(l);
                l = l + 1;
                enlarged = 1;
            end
        else
            s = s/zeta;
            enlarged = 1;
        end
        disp(s)
    elseif(enlarged == 0 && add_vertices > 0)
        index = convhulln(setP{i,1}.v');
        for k = 1:size(setP{i,1}.v,2)
            ve(:,k) = mean(setP{i,1}.v(:,index(k,:)),2);
        end
        setP{i,1}.v = [ve setP{i,1}.v];
        enlarged = 1;
        s = s0;
        l = 1;
        add_vertices = add_vertices-1;
    end
end
Kout = K{end};
setPout = setP{end};
disp(j)
disp(i)
disp(volume(Polyhedron(setP{end}.v'))/volume(Polyhedron(setX.v')));
if (size(setP0.v,1) == 2)
    figure, plot(Polyhedron(setX.v'),'alpha',0.35,'color','Blue'), grid, hold on;
    for i = size(setP,1):-1:1
        plot(Polyhedron(setP{i,1}.v'),'alpha',0.35,'color','Orange');
    end
    plot(0,0,'r*');
    legend('\bf{X}','\bf{P}');
    xlabel('x^{(1)}'), ylabel('x^{(2)}');
end
% addpath('C:\Program Files\Mosek\9.2\toolbox\R2015a');
end