function det_model_PMSM(omega0)
% Model parameters of the PMSM based on the reference speed
% 
% Rik Koch (TU Delft, 2021)

Vin = 220;
p = 6;
Rs = 1.5;
lambda_pm = 0.05;
Lq = 1.1e-4;
Ld = 3.5e-4;
JL = 0.019;
DL = 0.12;
TL0 = 30;
Ts = 1e-4;

global mdl;
mdl.Vin = Vin;
mdl.xe(1,1) = 0;
mdl.xe(2,1) = 2*(DL*omega0 + TL0)/(sqrt(3)*p*lambda_pm);
mdl.xe(3,1) = omega0;
mdl.ue(1,1) = -p*Lq*omega0*mdl.xe(2)/3;
mdl.ue(2,1) = (Rs*mdl.xe(2) + sqrt(3)*p*lambda_pm*omega0)/3;
mdl.A0 = [1-Rs*Ts/Ld 0 0;0 1-Rs*Ts/Lq -sqrt(3)*p*lambda_pm*Ts/Lq;...
    0 sqrt(3)*p*lambda_pm*Ts/(2*JL) 1-DL*Ts/JL];
mdl.A{1} = zeros(3);
mdl.A{1}(3,2) = p*Lq*Ts/Ld;
mdl.A{2} = zeros(3);
mdl.A{2}(3,1) = -p*Ld*Ts/Lq;
mdl.A{3} = zeros(3);
mdl.A{3}(1,2) = p*(Ld-Lq)*Ts/(2*JL);
mdl.B0 = [3*Ts/Ld 0;0 3*Ts/Lq;0 0];
mdl.A0 = mdl.A0 + [mdl.xe'*mdl.A{1};mdl.xe'*mdl.A{2};mdl.xe'*mdl.A{3}] + ...
    [mdl.xe'*mdl.A{1}';mdl.xe'*mdl.A{2}';mdl.xe'*mdl.A{3}'];
mdl.setX.v = interval2vert(kron([-1 1],[210;210;150]))' - mdl.xe;
mdl.setX.A = vert2con(mdl.setX.v')';
th = linspace(0,2*pi,9);
mdl.setU.v = (Vin/sqrt(3))*[cos(th(1:end-1));sin(th(1:end-1))] - mdl.ue;
[mdl.setU.M, mdl.setU.um] = vert2con(mdl.setU.v');

end