function y = sdnmpc_sampling_PMSM(x,par,Vin)
% Sampling function used for the three-phase VSI connected to a PMSM (see
% sdnmpc.m)
% 
% Rik Koch (TU Delft, 2021)

mu(1) = norm(par.mu)*sqrt(3)/Vin;
if (par.mu(1) < 0)
    mu(2) = atan(par.mu(2)/par.mu(1)) + pi;
elseif (par.mu(2) < 0)
    mu(2) = atan(par.mu(2)/par.mu(1)) + 2*pi;
else
    mu(2) = atan(par.mu(2)/par.mu(1));
end
switch par.method
    case 'trapezoidal'
        x(:,1) = unif2trap(sqrt(x(:,1)),mu(1),par.sigma(1));
        x(:,2) = 2*pi.*unif2trap(x(:,2),0.5,par.sigma(2)) + mu(2) - pi;
    case 'truncated normal'
        x(:,1) = unif2trunnorm(sqrt(x(:,1)),mu(1),par.sigma(1));
        x(:,2) = 2*pi.*unif2trunnorm(x(:,2),0.5,par.sigma(2)) + mu(2) - pi;
    case 'uniform bnd'
        x(:,1) = max(0, min(1, min(1, par.sigma(1)).*sqrt(x(:,1)) + mu(1) - min(0.5, par.sigma(1)/2)));
        x(:,2) = min(2*pi, par.sigma(2)).*x(:,2) + mu(2) - min(pi, par.sigma(2)/2);
    otherwise
        x(:,1) = sqrt(x(:,1));
        x(:,2) = 2*pi.*x(:,2);
end
y(:,1) = (Vin/sqrt(3)).*x(:,1).*cos(x(:,2));
y(:,2) = (Vin/sqrt(3)).*x(:,1).*sin(x(:,2));
end