function y = unif2trap(x,mu,sigma)
% Conversion from the uniform distribution to the trapezoidal distribution.
% y = unif2trap(x,mu,sigma)
% 
% inputs:
% x : samples with uniform distribution
% mu : mid point of the mode of the trapezoidal distribution
% sigma : extreme values of the mode of the trapezoidal distribution
% 
% outputs:
% y : samples with trapezoidal distribution
% 
% Rik Koch (TU Delft, 2021)

a = max(mu - sigma/2,0);
b = min(mu + sigma/2,1);
if (a > b)
    error('a must be less or equal to b');
end
y = zeros(size(x));
for i = 1:max(size(x))
    if (x(i) < a/(1+b-a))
        y(i) = sqrt((1+b-a)*a*x(i));
    elseif (x(i) < (2*b-a)/(1+b-a))
        y(i) = ((1+b-a)/2)*x(i) + (a/2);
    else
        y(i) = 1 - sqrt((1+b-a)*(1-b)*(1-x(i)));
    end
end