function y = unif2trunnorm(x,mu,sigma,varargin)
% Conversion from the uniform distribution to the truncated normal
% distribution
% y = unif2trunnorm(x,mu,sigma)
% y = unif2trunnorm(x,mu,sigma,a,b)
% 
% inputs:
% x : samples with uniform distribution
% mu : mean of the trapezoidal distribution
% sigma : standard deviation of the trapezoidal distribution
% [a,b] : interval of samples in truncated normal distribution (default
% [0,1])
% 
% outputs:
% y : samples with truncated normal distribution
% 
% Rik Koch (TU Delft, 2021)

if (nargin > 3)
    if (nargin > 4)
        a = varargin{1};
        b = varargin{2};
    else
        a = 0;
        b = varargin{1};
    end
else
    a = 0;
    b = 1;
end
alpha = (a - mu)/sigma;
beta = (b - mu)/sigma;
Z = 0.5*(erf(beta/sqrt(2)) - erf(alpha/sqrt(2)));
y = mu + sqrt(2)*sigma*erfinv(2*(Z.*x+0.5*(1+erf(alpha/sqrt(2))))-1);
end